@@ -16,13 +16,26 @@
  */
 
 
+#include <arpa/inet.h>
+#include <stdlib.h>
+#include <string.h>
+#include <errno.h>
 #include <zlib.h>
-#include "dcap_shared.h"
 
-ssize_t dc_real_read( struct vsp_node *node, void *buff, size_t buflen);
-ssize_t dc_pread64( int fd, void *buff, size_t buflen, off64_t);
-extern off64_t dc_real_lseek(struct vsp_node *node, off64_t offset, int whence);
-extern int dc_real_fsync(struct vsp_node *);
+#include "dcap.h"
+#include "dcap_functions.h"
+#include "dcap_read.h"
+#include "dcap_fsync.h"
+#include "dcap_lseek.h"
+#include "dcap_ahead.h"
+#include "dcap_reconnect.h"
+#include "dcap_protocol.h"
+#include "gettrace.h"
+#include "io.h"
+#include "node_plays.h"
+#include "system_io.h"
+#include "debug_level.h"
+#include "dcap_lcb.h"
 
 ssize_t
 dc_read(int fd, void *buff, size_t buflen)
@@ -44,7 +57,18 @@ dc_read(int fd, void *buff, size_t buflen)
 		return system_read(fd, buff, buflen);
 	}
 
-	n = dc_real_read(node, buff, buflen);
+	if ( node->lcb ) {
+		n = dc_lcb_read( node, buff, buflen );
+		if ( n < 0 ) {
+			/* print error */
+			dc_debug(DC_ERROR, "lcb_read: problems reading %d read, %d requsted, giving up lcb", n, buflen );
+			dc_lcb_clean( node );
+			n = dc_real_read(node, buff, buflen);
+		}
+	} else {
+		n = dc_real_read(node, buff, buflen);
+	}
+
 	m_unlock(&node->mux);
 
 	return n;
@@ -79,7 +103,11 @@ dc_pread64(int fd, void *buff, size_t buflen, off64_t offset)
 	}
 
 	if( dc_real_lseek(node, offset, SEEK_SET) >=0 ) {
-		n = dc_real_read(node, buff, buflen);
+		if ( node->lcb ) {
+			n = dc_lcb_read(node, buff, buflen);
+		} else {
+			n = dc_real_read(node, buff, buflen);
+		}
 	}
 
 	m_unlock(&node->mux);
@@ -90,9 +118,9 @@ dc_pread64(int fd, void *buff, size_t buflen, off64_t offset)
 
 
 ssize_t
-dc_real_read( struct vsp_node *node, void *buff, size_t buflen)
+dc_real_read( struct vsp_node *node, void *vbuff, size_t buflen)
 {
-
+	char *buff = vbuff;
 	int             tmp;
 	int32_t         readmsg[7]; /* keep one buffer for READ and SEEK_AND_READ*/
 	int              msglen;
