@@ -13,7 +13,6 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include "dcap_shared.h"
 #include "dcap_types.h"
 #include "dcap_errno.h"
 #include "dcap_error.h"
@@ -38,7 +37,7 @@ int main(int argc, char *argv[])
                         printf("  file: %s\n", url->file);
                         printf("  type: %d\n", url->type);
                         printf("  prefix: %s\n", url->prefix ? url->prefix : "none");
-                        printf("  config line: %s\n", url2config(url, str) );
+                        printf("  config line: %s\n", url2config(str, sizeof(str), url) );
                         free(url->host);
                         free(url->file);
                         if( url->prefix != NULL) free(url->prefix);
