@@ -9,8 +9,8 @@
  *   See the file COPYING.LIB
  *
  */
- 
- 
+
+
 /*
  * $Id: io.h,v 1.5 2004-11-01 19:33:30 tigran Exp $
  */
@@ -19,9 +19,7 @@
 
 #include "ioTunnel.h"
 
-extern int             readln(int, char *, int, ioTunnel *);
 extern int             readn(int, char *, int, ioTunnel *);
 extern int             writen(int, const char *, int, ioTunnel *);
-extern int             writeln(int, const char *, int, ioTunnel *);
 
 #endif
